@@ -40,7 +40,19 @@ class FakeAPI(object):
 
 
 class FakeResponse(object):
-    def __init__(self, headers):
+    def __init__(self, headers, body=None,
+                 version=1.0, status=200, reason="Ok"):
+        """
+        :param headers: dict representing HTTP response headers
+        :param body: file-like object
+        :param version: HTTP Version
+        :param status: Response status code
+        :param reason: Status code related message.
+        """
+        self.body = body
+        self.status = status
+        self.reason = reason
+        self.version = version
         self.headers = headers
 
     def getheaders(self):
@@ -48,3 +60,6 @@ class FakeResponse(object):
 
     def getheader(self, key, default):
         return self.headers.get(key, default)
+
+    def read(self, amt):
+        return self.body.read(amt)
